@@ -588,13 +588,20 @@ class Confluence(AtlassianRestAPI):
             url = 'rest/api/user?key={userkey}'.format(userkey=userkey)
         return self.get(url)
 
-    def cql(self, cql, start=0, limit=None):
+    def cql(self, cql, start=0, limit=None, expand=None, include_archived_spaces=None, excerpt=None):
         """
         Get results from cql search result with all related fields
+        Search for entities in Confluence using the Confluence Query Language (CQL)
         :param cql:
         :param start: OPTIONAL: The start point of the collection to return. Default: 0.
         :param limit: OPTIONAL: The limit of the number of issues to return, this may be restricted by
-                fixed system limits. Default by built-in method: 25
+                        fixed system limits. Default by built-in method: 25
+        :param excerpt: the excerpt strategy to apply to the result, one of : indexed, highlight, none.
+                        This defaults to highlight
+        :param expand: OPTIONAL: the properties to expand on the search result,
+                        this may cause database requests for some properties
+        :param include_archived_spaces: OPTIONAL: whether to include content in archived spaces in the result,
+                                    this defaults to false
         :return:
         """
         params = {}
@@ -604,6 +611,13 @@ class Confluence(AtlassianRestAPI):
             params["limit"] = int(limit)
         if cql is not None:
             params['cql'] = cql
+        if expand is not None:
+            params['expand'] = expand
+        if include_archived_spaces is not None:
+            params['includeArchivedSpaces'] = include_archived_spaces
+        if excerpt is not None:
+            params['excerpt'] = excerpt
+
         return self.get('rest/api/search', params=params)
 
     def get_page_as_pdf(self, page_id):
